WalMirror

Trait WalMirror 

pub trait WalMirror: Send + Sync {
    // Required method
    fn persist(&self, wal_dir: &Path) -> Result<(), WalError>;

    // Provided method
    fn persist_force(&self, wal_dir: &Path) -> Result<(), WalError> { ... }
}
Optional side-effect after the WAL has successfully flushed.

The core WAL stays directory/segment based for append performance. Higher layers can install a mirror to copy that durable directory into another representation, such as the portable .loradb archive file used by named databases.

Required Methods

fn persist(&self, wal_dir: &Path) -> Result<(), WalError>

Provided Methods

fn persist_force(&self, wal_dir: &Path) -> Result<(), WalError>

Implementors